package Alien::sispmctl;
BEGIN {
  $Alien::sispmctl::AUTHORITY = 'cpan:GETTY';
}
# ABSTRACT: Silver Shield PM Control for Linux
$Alien::sispmctl::VERSION = '0.001';
use parent 'Alien::Base';

1;

__END__

=pod

=head1 NAME

Alien::sispmctl - Silver Shield PM Control for Linux

=head1 VERSION

version 0.001

=head1 AUTHOR

Torsten Raudssus <torsten@raudss.us>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by Torsten Raudssus.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
